summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRaimo Niskanen <raimo@erlang.org>2017-11-01 12:30:15 +0100
committerRaimo Niskanen <raimo@erlang.org>2017-11-01 12:30:15 +0100
commit4604c73f8f5192b1eb33ca2b6eda7200c43a8a8d (patch)
treea4a5f5f838f4c6c6cadfa1ddb5adf05f1b809fab
parent84e3ce67e27ea9da607402a030f9e757854f3b76 (diff)
downloaderlang-4604c73f8f5192b1eb33ca2b6eda7200c43a8a8d.tar.gz
Tweak statistics limits
-rw-r--r--lib/stdlib/test/rand_SUITE.erl8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/stdlib/test/rand_SUITE.erl b/lib/stdlib/test/rand_SUITE.erl
index e256d31112..3d3241b33d 100644
--- a/lib/stdlib/test/rand_SUITE.erl
+++ b/lib/stdlib/test/rand_SUITE.erl
@@ -480,13 +480,13 @@ stats_standard_normal(Config) when is_list(Config) ->
stats_standard_normal(Fun, S) ->
%%%
%%% ct config:
-%%% {rand_SUITE, [{stats_standard_normal,[{seconds, 8}, {std_devs, 4.0}]}]}.
+%%% {rand_SUITE, [{stats_standard_normal,[{seconds, 8}, {std_devs, 4.2}]}]}.
%%%
Seconds = ct:get_config({?MODULE, ?FUNCTION_NAME, seconds}, 8),
StdDevs =
ct:get_config(
{?MODULE, ?FUNCTION_NAME, std_devs},
- 4.0), % probability erfc(4/sqrt(2)) (1/15787) to fail a bucket
+ 4.2), % probability erfc(4.2/sqrt(2)) (1/37465) to fail a bucket
%%%
ct:timetrap({seconds, Seconds + 120}),
%% Buckets is chosen to get a range where the the probability to land
@@ -528,9 +528,9 @@ stats_standard_normal(Fun, S) ->
W, TotalRounds, StdDevs, PositiveHistogram, Buckets),
check_histogram(
W, TotalRounds, StdDevs, NegativeHistogram, Buckets)},
%% If the probability for getting this Outlier is lower than 1/20,
%% then this is fishy!
- true = (1/20 =< OutlierProbability),
+ true = (1/50 =< OutlierProbability),
{comment, {tp, TopPrecision, op, InvOP}}.
%%
stats_standard_normal(
@@ -528,9 +528,9 @@ stats_standard_normal(Fun, S) ->
check_histogram(
W, TotalRounds, StdDevs, NegativeHistogram, Buckets)},
- %% If the probability for getting this Outlier is lower than 1/20,
+ %% If the probability for getting this Outlier is lower than 1/50,
%% then this is fishy!